==> heptapod-rails-0.20.7.tar.gz: heptapod-rails-0.20.7/scripts/heptapod-make-push-tarball.sh <==
#!/bin/sh

set -e

if echo "$CI_COMMIT_TAG" | grep '^heptapod-' > /dev/null; then
    TARBALL=$(echo -n $CI_COMMIT_TAG | sed s/heptapod/heptapod-rails/g)
    # pulling on the current branch and the two main heptapod ones
    # so that `hg archive` should see the tag (very unlikely the tagging
    # changeset would be elsewhere, not worth pulling the whole repo)
    # using `hg log` instead of `hg branch` to avoid newline for safety
    hg pull -q -r heptapod -r heptapod-stable -r heptapod-oldstable -r `hg log -r. -T "{branch}"` || /bin/true
    SUBDIR=public
    # why three greps and not a single `else` case? To avoid painful
    # release commit and tag creation in the wrong branch of omninus-heptapod
    # if, e.g.,  we change the name of the CI image and forget to update this
    # script.
    if grep ci-images/heptapod-base:oldstable heptapod-ci.yml >/dev/null; then
        TRIGGER_OMNIBUS_BRANCH=heptapod-oldstable
    elif grep ci-images/heptapod-base:stable heptapod-ci.yml >/dev/null; then
        TRIGGER_OMNIBUS_BRANCH=heptapod-stable
    elif grep ci-images/heptapod-base:default heptapod-ci.yml >/dev/null; then
        TRIGGER_OMNIBUS_BRANCH=heptapod
    else
        echo "Could not determine the target omnibus-heptapod branch" >&2
        echo "For commit/tag creation. Aborting." >&2
        exit 1
    fi
    echo "Target Omnibus branch for automatic release creation: $TRIGGER_OMNIBUS_BRANCH"
else
    TARBALL=heptapod-rails-$(hg log -r. -T "{node}")
    SUBDIR=public/intermediate
    TRIGGER_OMNIBUS_BRANCH=
fi

# it's nicer for console output to add the extension right away
TARBALL=${TARBALL}.tar.gz

TARBALL_PATH=/tmp/${TARBALL}

echo "Generating ${TARBALL}"
hg archive -t tgz ${TARBALL_PATH}
echo "Generating SHA-256 checksum"
sha256sum ${TARBALL_PATH} > ${TARBALL_PATH}.sha256sum
cat ${TARBALL_PATH}.sha256sum

if [ -n "$HEPTAPOD_PACKAGING_GPG_PRIVKEY" ]; then
    `dirname $0`/heptapod-sign-package $HEPTAPOD_PACKAGING_GPG_PRIVKEY \
                $TARBALL_PATH
else
    echo "Key not present, skipping GPG signature. "
    echo "    This is normal on non-protected tags and branches"
fi

if [ -n "$HEPTAPOD_TARBALL_UPLOAD_KEY" ]; then
    `dirname $0`/heptapod-sftp-push \
                upload.heptapod.net \
                "$HEPTAPOD_TARBALL_UPLOAD_KEY" \
                "$TARBALL_PATH" \
                "${SUBDIR}/src"
fi

echo

HGRCPATH=/tmp/job.hgrc
export HGRCPATH
cat > $HGRCPATH <<EOF
[extensions]
topic=
evolve=

[ui]
username = "Heptapod Release Bot <heptapod-release.bot@heptapod.net>"
EOF

# we prefer the waste of cloning to tmp rather than an untested update script
HEPTAPOD_OMNIBUS_CLONE=/tmp/omnibus-heptapod
HEPTAPOD_OMNIBUS_REPO=foss.heptapod.net/heptapod/omnibus-heptapod

if [ -z "$HEPTAPOD_OMNIBUS_ACCESS_CREDS" ]; then
echo "No credentials to push to omnibus-heptapod repo."
fi

if [ -n "$TRIGGER_OMNIBUS_BRANCH" -a -n "$HEPTAPOD_OMNIBUS_ACCESS_CREDS" ]; then
    # here it would be nice to give remotefilelog a try
    # in this case we want to be 100% sure not to miss a tag, hence no -r
    hg clone -u ${TRIGGER_OMNIBUS_BRANCH} \
       https://${HEPTAPOD_OMNIBUS_REPO} \
       $HEPTAPOD_OMNIBUS_CLONE

    echo -n $CI_COMMIT_TAG | sed s/heptapod-//g > ${HEPTAPOD_OMNIBUS_CLONE}/HEPTAPOD_VERSION
    cut -f1 -d ' ' ${TARBALL_PATH}.sha256sum > ${HEPTAPOD_OMNIBUS_CLONE}/HEPTAPOD_RAILS_SHA256
    cp HEPTAPOD_SHELL_VERSION ${HEPTAPOD_OMNIBUS_CLONE}/

    echo "Committing version files"
    hg commit -R ${HEPTAPOD_OMNIBUS_CLONE} -qm "Updated version files for release"
    echo "Done as:"
    hg export -R ${HEPTAPOD_OMNIBUS_CLONE} .

    # Omnibus maintains an additional -1 build number.
    OMNIBUS_TAG=${CI_COMMIT_TAG}-1
    echo "Attempting to create tag ${OMNIBUS_TAG}. In case of failure, "
    echo "especially because the tag already exists, please finish manually."
    hg tag -f -R ${HEPTAPOD_OMNIBUS_CLONE} ${OMNIBUS_TAG}
    echo "Done as:"
    hg log -R ${HEPTAPOD_OMNIBUS_CLONE} -r .

    hg push -R ${HEPTAPOD_OMNIBUS_CLONE} -r . \
       https://${HEPTAPOD_OMNIBUS_ACCESS_CREDS}@${HEPTAPOD_OMNIBUS_REPO}
fi

==> heptapod-rails-0.21.0rc1.tar.gz: heptapod-rails-0.21.0rc1/scripts/heptapod-make-push-tarball.sh <==
#!/bin/sh

set -e

if echo "$CI_COMMIT_TAG" | grep '^heptapod-' > /dev/null; then
    TARBALL=$(echo -n $CI_COMMIT_TAG | sed s/heptapod/heptapod-rails/g)
    # pulling on the current branch and the two main heptapod ones
    # so that `hg archive` should see the tag (very unlikely the tagging
    # changeset would be elsewhere, not worth pulling the whole repo)
    # using `hg log` instead of `hg branch` to avoid newline for safety
    hg pull -q -r heptapod -r heptapod-stable -r `hg log -r. -T "{branch}"` || /bin/true
    SUBDIR=public

    # why two greps and not a single `else` case? To avoid painful
    # release commit and tag creation in the wrong branch of omninus-heptapod
    # if, e.g.,  we change the name of the CI image and forget to update this
    # script.
    if grep ci-images/heptapod-base:stable heptapod-ci.yml >/dev/null; then
        TRIGGER_OMNIBUS_BRANCH=heptapod-stable
    elif grep ci-images/heptapod-base:default heptapod-ci.yml >/dev/null; then
        TRIGGER_OMNIBUS_BRANCH=heptapod
    else
        echo "Could not determine the target omnibus-heptapod branch" >&2
        echo "For commit/tag creation. Aborting." >&2
        exit 1
    fi
    echo "Target Omnibus branch for automatic release creation: $TRIGGER_OMNIBUS_BRANCH"
else
    TARBALL=heptapod-rails-$(hg log -r. -T "{node}")
    SUBDIR=public/intermediate
    TRIGGER_OMNIBUS_BRANCH=
fi

# it's nicer for console output to add the extension right away
TARBALL=${TARBALL}.tar.gz

TARBALL_PATH=/tmp/${TARBALL}

echo "Generating ${TARBALL}"
hg archive -t tgz ${TARBALL_PATH}
echo "Generating SHA-256 checksum"
sha256sum ${TARBALL_PATH} > ${TARBALL_PATH}.sha256sum
cat ${TARBALL_PATH}.sha256sum

if [ -n "$HEPTAPOD_TARBALL_UPLOAD_KEY" ]; then
    `dirname $0`/heptapod-sftp-push \
                upload.heptapod.net \
                "$HEPTAPOD_TARBALL_UPLOAD_KEY" \
                "$TARBALL_PATH" \
                "${SUBDIR}/src"
fi

echo

HGRCPATH=/tmp/job.hgrc
export HGRCPATH
cat > $HGRCPATH <<EOF
[extensions]
topic=
evolve=

[ui]
username = "Heptapod Release Bot <heptapod-release.bot@heptapod.net>"
EOF

# we prefer the waste of cloning to tmp rather than an untested update script
HEPTAPOD_OMNIBUS_CLONE=/tmp/omnibus-heptapod
HEPTAPOD_OMNIBUS_REPO=foss.heptapod.net/heptapod/omnibus-heptapod

if [ -z "$HEPTAPOD_OMNIBUS_ACCESS_CREDS" ]; then
echo "No credentials to push to omnibus-heptapod repo."
fi

if [ -n "$TRIGGER_OMNIBUS_BRANCH" -a -n "$HEPTAPOD_OMNIBUS_ACCESS_CREDS" ]; then
    # here it would be nice to give remotefilelog a try
    # in this case we want to be 100% sure not to miss a tag, hence no -r
    hg clone -u ${TRIGGER_OMNIBUS_BRANCH} \
       https://${HEPTAPOD_OMNIBUS_REPO} \
       $HEPTAPOD_OMNIBUS_CLONE

    echo -n $CI_COMMIT_TAG | sed s/heptapod-//g > ${HEPTAPOD_OMNIBUS_CLONE}/HEPTAPOD_VERSION
    cut -f1 -d ' ' ${TARBALL_PATH}.sha256sum > ${HEPTAPOD_OMNIBUS_CLONE}/HEPTAPOD_RAILS_SHA256
    cp HEPTAPOD_SHELL_VERSION ${HEPTAPOD_OMNIBUS_CLONE}/

    echo "Committing version files"
    hg commit -R ${HEPTAPOD_OMNIBUS_CLONE} -qm "Updated version files for release"
    echo "Done as:"
    hg export -R ${HEPTAPOD_OMNIBUS_CLONE} .

    # Omnibus maintains an additional -1 build number.
    OMNIBUS_TAG=${CI_COMMIT_TAG}-1
    echo "Attempting to create tag ${OMNIBUS_TAG}. In case of failure, "
    echo "especially because the tag already exists, please finish manually."
    hg tag -R ${HEPTAPOD_OMNIBUS_CLONE} ${OMNIBUS_TAG}
    echo "Done as:"
    hg log -R ${HEPTAPOD_OMNIBUS_CLONE} -r .

    hg push -R ${HEPTAPOD_OMNIBUS_CLONE} -r . \
       https://${HEPTAPOD_OMNIBUS_ACCESS_CREDS}@${HEPTAPOD_OMNIBUS_REPO}
fi
